==> gds-2.17.1.tar.gz: gds-2.17.1/DMT/osc3/strtok_r.cc <==
// Yo, Emacs! This is -*- C++ -*-
//
// $Id: strtok_r.cc 27 2001-09-29 01:59:00Z john.zweizig $
//

#include <stdlib.h>

namespace osc
{
    /* This code for strtok_r() is from:
     * http://www.ajk.tele.fi/libc/string/strtok_r.c.html
     */
    /*
     * Copyright (c) 1988 Regents of the University of California.
     * All rights reserved.
     *
     * Redistribution and use in source and binary forms, with or without
     * modification, are permitted provided that the following conditions
     * are met:
     * 1. Redistributions of source code must retain the above copyright
     *    notice, this list of conditions and the following disclaimer.
     * 2. Redistributions in binary form must reproduce the above copyright
     *    notice, this list of conditions and the following disclaimer in the
     *    documentation and/or other materials provided with the distribution.
     * 3. All advertising materials mentioning features or use of this software
     *    must display the following acknowledgement:
     *      This product includes software developed by the University of
     *      California, Berkeley and its contributors.
     * 4. Neither the name of the University nor the names of its contributors
     *    may be used to endorse or promote products derived from this software
     *    without specific prior written permission.
     *
     * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS''
     * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
     * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
     * PARTICULAR PURPOSE * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS
     * OR CONTRIBUTORS BE LIABLE * FOR ANY DIRECT, INDIRECT, INCIDENTAL,
     * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL * DAMAGES (INCLUDING, BUT NOT
     * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS * OR SERVICES; LOSS OF
     * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) * HOWEVER CAUSED
     * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT *
     * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
     * ANY WAY * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
     * POSSIBILITY OF * SUCH DAMAGE.
     */

    char *strtok_r(register char *s,
                   register const char *delim,
                   register char **lasts)
    {
        register char *spanp;
        register int c, sc;
        char *tok;

        if (s == NULL && (s = *lasts) == NULL)
            return (NULL);

        /*
         * Skip (span) leading delimiters (s += strspn(s, delim), sort of).
         */
    cont:
        c = *s++;
        for (spanp = (char *)delim; (sc = *spanp++) != 0;) {
            if (c == sc)
                goto cont;
        }

        if (c == 0) {           /* no non-delimiter characters */
            *lasts = NULL;
            return (NULL);
        }
        tok = s - 1;

        /*
         * Scan token (scan for delimiters: s += strcspn(s, delim), sort of).
         * Note that delim must have one NUL; we stop if we see that, too.
         */
        for (;;) {
            c = *s++;
            spanp = (char *)delim;
            do {
                if ((sc = *spanp++) == c) {
                    if (c == 0)
                        s = NULL;
                    else
                        s[-1] = 0;
                    *lasts = s;
                    return (tok);
                }
            } while (sc != 0);
        }
        /* NOTREACHED */
    }

};  // namespace osc

==> gds-2.18.5.tar.gz: gds-2.18.5/DMT/osc3/strtok_r.cc <==
// Yo, Emacs! This is -*- C++ -*-
//
// $Id: strtok_r.cc 7524 2015-11-19 01:18:08Z ed.maros@LIGO.ORG $
//

#include <stdlib.h>

namespace osc
{
    /* This code for strtok_r() is from:
     * http://www.ajk.tele.fi/libc/string/strtok_r.c.html
     */
    /*
     * Copyright (c) 1988 Regents of the University of California.
     * All rights reserved.
     *
     * Redistribution and use in source and binary forms, with or without
     * modification, are permitted provided that the following conditions
     * are met:
     * 1. Redistributions of source code must retain the above copyright
     *    notice, this list of conditions and the following disclaimer.
     * 2. Redistributions in binary form must reproduce the above copyright
     *    notice, this list of conditions and the following disclaimer in the
     *    documentation and/or other materials provided with the distribution.
     * 3. All advertising materials mentioning features or use of this software
     *    must display the following acknowledgement:
     *      This product includes software developed by the University of
     *      California, Berkeley and its contributors.
     * 4. Neither the name of the University nor the names of its contributors
     *    may be used to endorse or promote products derived from this software
     *    without specific prior written permission.
     *
     * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS''
     * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
     * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
     * PARTICULAR PURPOSE * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS
     * OR CONTRIBUTORS BE LIABLE * FOR ANY DIRECT, INDIRECT, INCIDENTAL,
     * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL * DAMAGES (INCLUDING, BUT NOT
     * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS * OR SERVICES; LOSS OF
     * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) * HOWEVER CAUSED
     * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT *
     * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
     * ANY WAY * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
     * POSSIBILITY OF * SUCH DAMAGE.
     */

    char *strtok_r(char *s,
                   const char *delim,
                   char **lasts)
    {
        char *spanp;
        int c, sc;
        char *tok;

        if (s == NULL && (s = *lasts) == NULL)
            return (NULL);

        /*
         * Skip (span) leading delimiters (s += strspn(s, delim), sort of).
         */
    cont:
        c = *s++;
        for (spanp = (char *)delim; (sc = *spanp++) != 0;) {
            if (c == sc)
                goto cont;
        }

        if (c == 0) {           /* no non-delimiter characters */
            *lasts = NULL;
            return (NULL);
        }
        tok = s - 1;

        /*
         * Scan token (scan for delimiters: s += strcspn(s, delim), sort of).
         * Note that delim must have one NUL; we stop if we see that, too.
         */
        for (;;) {
            c = *s++;
            spanp = (char *)delim;
            do {
                if ((sc = *spanp++) == c) {
                    if (c == 0)
                        s = NULL;
                    else
                        s[-1] = 0;
                    *lasts = s;
                    return (tok);
                }
            } while (sc != 0);
        }
        /* NOTREACHED */
    }

};  // namespace osc
